package com.sf.service.gateway.mapper;

import com.sf.service.gateway.domain.GatewayStrategy;
import org.apache.ibatis.annotations.Param;

import java.util.Collection;
import java.util.List;

/**
 * 策略管理Mapper接口
 * 
 * @author zoukun
 * @date 2024-04-22
 */
public interface GatewayStrategyMapper 
{
    /**
     * 查询策略管理
     * 
     * @param id 策略管理主键
     * @return 策略管理
     */
    public GatewayStrategy selectGatewayStrategyById(Long id);

    /**
     * 查询策略管理列表
     * 
     * @param gatewayStrategy 策略管理
     * @return 策略管理集合
     */
    public List<GatewayStrategy> selectGatewayStrategyList(GatewayStrategy gatewayStrategy);

    /**
     * 新增策略管理
     * 
     * @param gatewayStrategy 策略管理
     * @return 结果
     */
    public int insertGatewayStrategy(GatewayStrategy gatewayStrategy);

    /**
     * 修改策略管理
     * 
     * @param gatewayStrategy 策略管理
     * @return 结果
     */
    public int updateGatewayStrategy(GatewayStrategy gatewayStrategy);

    /**
     * 删除策略管理
     * 
     * @param id 策略管理主键
     * @return 结果
     */
    public int deleteGatewayStrategyById(Long id);

    /**
     * 批量删除策略管理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteGatewayStrategyByIds(Long[] ids);

    int updateGatewayStrategyStatusByIds(@Param("ids") List<Long> ids, @Param("status") String status);

    List<GatewayStrategy> selectGatewayStrategyByIds(@Param("ids") Collection<Long> ids);
}
